"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const context_1 = tslib_1.__importDefault(require("./context"));
const QuizQuestions_1 = tslib_1.__importDefault(require("../QuizQuestions"));
const ResultContainer_1 = tslib_1.__importDefault(require("../ResultContainer/ResultContainer"));
const ControlBar_1 = tslib_1.__importDefault(require("../ControlBar/ControlBar"));
const constants_1 = require("../../constants");
const Spinner_1 = tslib_1.__importDefault(require("../Spinner/Spinner"));
const useQuiz_1 = tslib_1.__importDefault(require("../../hooks/useQuiz"));
const SessionPromptModal_1 = tslib_1.__importDefault(require("../SessionPromptModal/SessionPromptModal"));
const ShareResultsModal_1 = tslib_1.__importDefault(require("../ShareResultsModal/ShareResultsModal"));
const utils_1 = require("../../utils");
const ProgressBar_1 = tslib_1.__importDefault(require("../ProgressBar/ProgressBar"));
function CioQuiz(props) {
    var _a;
    const { cioClient, state, events: { hydrateQuiz, resetSessionStorageState }, getAddToCartButtonProps, getAddToFavoritesButtonProps, getCoverQuestionProps, getHydrateQuizButtonProps, getNextQuestionButtonProps, getSkipQuestionButtonProps, getOpenTextInputProps, getPreviousQuestionButtonProps, getQuizImageProps, getQuizResultButtonProps, getQuizResultLinkProps, getResetQuizButtonProps, getSelectInputProps, primaryColorStyles, getShareResultsButtonProps, } = (0, useQuiz_1.default)(props);
    const [showSessionPrompt, setShowSessionPrompt] = (0, react_1.useState)(false);
    const [showShareModal, setShowShareModal] = (0, react_1.useState)(false);
    const { callbacks, sessionStateOptions, questionsPageOptions, resultCardOptions, resultsPageOptions, } = props;
    const { quizSessionStorageState: { hasSessionStorageState, skipToResults }, } = state;
    (0, react_1.useEffect)(() => {
        // Respect showSessionModal if defined, else default to true.
        if ((sessionStateOptions === null || sessionStateOptions === void 0 ? void 0 : sessionStateOptions.showSessionModal) !== undefined) {
            setShowSessionPrompt((sessionStateOptions === null || sessionStateOptions === void 0 ? void 0 : sessionStateOptions.showSessionModal) && hasSessionStorageState() && !skipToResults);
        }
        else {
            setShowSessionPrompt(hasSessionStorageState() && !skipToResults);
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    const contextValue = {
        cioClient,
        state,
        getAddToCartButtonProps,
        getAddToFavoritesButtonProps,
        getCoverQuestionProps,
        getHydrateQuizButtonProps,
        getNextQuestionButtonProps,
        getSkipQuestionButtonProps,
        getOpenTextInputProps,
        getPreviousQuestionButtonProps,
        getQuizImageProps,
        getQuizResultButtonProps,
        getQuizResultLinkProps,
        getResetQuizButtonProps,
        getShareResultsButtonProps,
        getSelectInputProps,
        customClickItemCallback: !!(callbacks === null || callbacks === void 0 ? void 0 : callbacks.onQuizResultClick),
        customAddToFavoritesCallback: !!(callbacks === null || callbacks === void 0 ? void 0 : callbacks.onAddToFavoritesClick),
        primaryColorStyles,
    };
    if (state.quiz.requestState === constants_1.RequestStates.Loading) {
        return (react_1.default.createElement("div", { className: 'cio-quiz cio-quiz-loading' },
            react_1.default.createElement(Spinner_1.default, null)));
    }
    const questionData = (_a = state.quiz.currentQuestion) === null || _a === void 0 ? void 0 : _a.next_question;
    const questionType = questionData === null || questionData === void 0 ? void 0 : questionData.type;
    const questionImages = questionData === null || questionData === void 0 ? void 0 : questionData.images;
    const displayBackgroundImage = (questionType === 'single' || questionType === 'multiple') && questionImages;
    if (state.quiz.requestState === constants_1.RequestStates.Success) {
        return (react_1.default.createElement("div", { className: 'cio-quiz', style: { overflow: showShareModal || showSessionPrompt ? 'hidden' : undefined } },
            displayBackgroundImage && (0, utils_1.renderImages)(questionImages, 'cio-question-background-image'),
            react_1.default.createElement("style", null,
                ".cio-quiz ",
                (0, utils_1.convertPrimaryColorsToString)(primaryColorStyles)),
            react_1.default.createElement(SessionPromptModal_1.default, { resetStoredState: resetSessionStorageState, continueSession: hydrateQuiz, showSessionPrompt: showSessionPrompt, setShowSessionPrompt: setShowSessionPrompt }),
            state.quiz && showShareModal && (react_1.default.createElement(ShareResultsModal_1.default, { onClose: () => setShowShareModal(false), quizState: state.quiz, onEmailResults: callbacks === null || callbacks === void 0 ? void 0 : callbacks.onEmailResults })),
            react_1.default.createElement(context_1.default.Provider, { value: contextValue }, state.quiz.results || skipToResults ? (react_1.default.createElement(ResultContainer_1.default, { resultCardOptions: resultCardOptions, onShare: () => setShowShareModal(true), resultsPageOptions: resultsPageOptions })) : (state.quiz.currentQuestion && (react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement(ProgressBar_1.default, null),
                react_1.default.createElement(QuizQuestions_1.default, null),
                react_1.default.createElement(ControlBar_1.default, { skipQuestionButtonText: questionsPageOptions === null || questionsPageOptions === void 0 ? void 0 : questionsPageOptions.skipQuestionButtonText, ctaButtonText: (questionData === null || questionData === void 0 ? void 0 : questionData.cta_text) || undefined })))))));
    }
    return null;
}
exports.default = CioQuiz;
